# Make accessbile the required functions.

source("phylcon_fn.q")

# Read in the data frame of pvalues into pmat. The data frame for some functions
# requires p-values with genes along rows and topologies along columns. In the
# example file fakg05pval.txt, the opposite is true and there is a header line
# containing the names of the genes. The R function t() can be used to transpose
# the matrix at any time.

pmat <- read.table("example.txt", header=T)
pmat <- t(pmat) # transpose so that gene x top


# An image plot with no ordering and a color key. The break points for different
# colours for the p-values are set in brks as 0.00,0.05,...,0.95,1.00. 

brks <-  seq(0.00,1.0,0.05)
grid <- expand.grid(x=c(1:dim(pmat)[1]), y=c(1:dim(pmat)[2]))
grid$z <- c(pmat)
print(levelplot(z~x*y, data = grid, col.regions =  terrain.colors(100),
                at = brks, xlab = "Genes", main = "Example Data",
                ylab = "Topology", 
                colorkey = list(at = brks, labels = as.character(brks)) ))

# A heat map with two way clustering and dendrogram.

heatmap.d(t(pmat), nclust.row = 1, nclust.col = 1,
          scale = "none", ylab = "Topology", xlab = "Gene",
          labRow = rep("",dim(t(pmat))[1]), # no row labels
          labCol = rep("",dim(t(pmat))[2]), # no col labels
          col = terrain.colors(20), main = "Example Data",
          breaks = brks)

# A heat map with two way clustering and no dendrogram. For this example data
# set, simulated genes were mixed with true genes. It is useful to add colour
# labels indicated where they ended up being located after two-way clustering. 

rc <- col.groupgenes(dim(pmat)[1], 205) # The first 205 genes were true genes.
heatmap.nod(t(pmat), nclust.row = 1, nclust.col = 1, method = "average",
            xlab = "Gene", ylab = "Topology", ttl = "Example Data",
            ColSideColors = rc, # the colours indicating true genes
            col = terrain.colors(20), breaks = brks, axes = T)

# The indeces of the topologies for which a majority of (true) genes have p-value >=
# alpha.

idxsub <- plaus.top(pmat[1:205,], alpha = 0.05)
pmat.plaus <- pmat[,idxsub]

# A heatmap with clusters indicated.

heatmap.nod(t(pmat.plaus), divisive = F,
            nclust.row = 4, # number of clusters of topogies
            nclust.col = 6, # number of clusters of genes
            ColSideColors = rc, 
            ylab = "Topology", xlab = "Gene", ttl = "Example Data",
            col = terrain.colors(20), 
            breaks = brks, axes = T)

